diff libpurple/protocols/qq/qq_proxy.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/qq_proxy.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/qq_proxy.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file qq_proxy.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -34,13 +34,13 @@
 #define QQ_CONNECT_STEPS    2	/* steps in connection */
 
 struct PHB {
-	GaimProxyConnectFunction func;
+	PurpleProxyConnectFunction func;
 	gpointer data;
 	gchar *host;
 	gint port;
 	gint inpa;
-	GaimProxyInfo *gpi;
-	GaimAccount *account;
+	PurpleProxyInfo *gpi;
+	PurpleAccount *account;
 	gint udpsock;
 	gpointer sockbuf;
 };
@@ -48,8 +48,8 @@
 gint qq_proxy_read(qq_data *qd, guint8 *data, gint len);
 gint qq_proxy_write(qq_data *qd, guint8 *data, gint len);
 
-gint qq_connect(GaimAccount *account, const gchar *host, guint16 port, gboolean use_tcp, gboolean is_redirect);
-void qq_disconnect(GaimConnection *gc);
+gint qq_connect(PurpleAccount *account, const gchar *host, guint16 port, gboolean use_tcp, gboolean is_redirect);
+void qq_disconnect(PurpleConnection *gc);
 
 void _qq_show_packet(const gchar *desc, const guint8 *buf, gint len);
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.